package javax.activation;

import java.util.WeakHashMap;
import java.util.Map;

public abstract class CommandMap
{
    private static CommandMap defaultCommandMap;
    private static Map<ClassLoader, CommandMap> map;
    
    public CommandMap() {
    }
    
    public static synchronized CommandMap getDefaultCommandMap() {
        if (CommandMap.defaultCommandMap != null) {
            return CommandMap.defaultCommandMap;
        }
        ClassLoader tccl = SecuritySupport.getContextClassLoader();
        CommandMap def = (CommandMap)CommandMap.map.get(tccl);
        if (def == null) {
            def = new MailcapCommandMap();
            CommandMap.map.put(tccl, def);
            return def;
        }
        return def;
    }
    
    public static synchronized void setDefaultCommandMap(CommandMap commandMap) {
        SecurityManager security = System.getSecurityManager();
        if (security != null) {
            try {
                security.checkSetFactory();
            }
            catch (SecurityException ex) {
                if (CommandMap.class.getClassLoader() == null || CommandMap.class.getClassLoader() != commandMap.getClass().getClassLoader()) {
                    throw ex;
                }
            }
        }
        CommandMap.map.remove(SecuritySupport.getContextClassLoader());
        CommandMap.defaultCommandMap = commandMap;
    }
    
    public abstract CommandInfo[] getPreferredCommands(String p0);
    
    public CommandInfo[] getPreferredCommands(String mimeType, DataSource ds) {
        return this.getPreferredCommands(mimeType);
    }
    
    public abstract CommandInfo[] getAllCommands(String p0);
    
    public CommandInfo[] getAllCommands(String mimeType, DataSource ds) {
        return this.getAllCommands(mimeType);
    }
    
    public abstract CommandInfo getCommand(String p0, String p1);
    
    public CommandInfo getCommand(String mimeType, String cmdName, DataSource ds) {
        return this.getCommand(mimeType, cmdName);
    }
    
    public abstract DataContentHandler createDataContentHandler(String p0);
    
    public DataContentHandler createDataContentHandler(String mimeType, DataSource ds) {
        return this.createDataContentHandler(mimeType);
    }
    
    public String[] getMimeTypes() {
        return null;
    }
    
    static {
        CommandMap.defaultCommandMap = null;
        CommandMap.map = new WeakHashMap();
    }
}
